import axios from 'axios'
import {Loading, Message} from 'element-ui'
import selfConfig from '../../../config/selfConfig'
//element Message配置
const ERROR_MSG_OP = {showClose: true, duration: 1000};
const SUCC_MSG_OP = {showClose: true, duration: 1000};
const INFO_MSG_OP = {showClose: true, duration: 1000};

// 超时时间
// axios.defaults.timeout = 8000
axios.defaults.baseURL = selfConfig.API_SERVER
axios.defaults.headers.post['Content-Type'] = 'application/json'
axios.defaults.withCredentials = true
axios.defaults.transformRequest = function (request) {
	return JSON.stringify(request)
}

// http请求拦截器
axios.interceptors.request.use(function (config) {
	return config
}, function (error) {
	Message.error({message: '请求错误', ...ERROR_MSG_OP});
	return Promise.reject(error)
})

// http响应拦截器
axios.interceptors.response.use(function (res) {
	if (res.data.returnCode === 103) {
		window.location.href = selfConfig.LOGIN_PATH
	}
	if (res.config.showTip) {
		// 如果returnCode=200，表示操作正常完成
		if (res.data.returnCode === '200') {
			var msg = res.data.returnMsg ? res.data.returnMsg : '操作成功!';
			Message.success({message: msg, ...SUCC_MSG_OP});
		} else { // 如果非等于200，代表操作失败。则给出操作失败的原因。如：因为有关系数据不能正常删除等。
			if (res.data.returnCode === '499') {
				Message.error({message: '操作失败！', ...ERROR_MSG_OP});
			} else {
				msg = res.data.returnMsg ? res.data.returnMsg : '操作失败！';
				Message.error({message: msg, ...ERROR_MSG_OP});
			}
		}
	}
	return res
}, function (error) {
	Message.error({message: '请求错误', ...ERROR_MSG_OP})
	return Promise.reject(error)
})
export default axios
